#include <Arduboy2.h>
#include "HUMAN.h"

#define HUMAN       0
#define LIZARDMAN   1
#define MOUSEMAN    2
#define PIRANHAMAN  3
#define LIONMAN     4
#define HAWKMAN     5

Arduboy2 arduboy;
Sprites sprites;

byte heroT = HUMAN; // hero type
byte heroX = 64;  // hero's horizontal-middle position
byte heroY = 64;  // hero's vertical-bottom position
byte anim = 0;  // used in common by several animations
boolean heroR = true;  // hero is facing right direction
boolean heroD = false; // hero is crouching / Mouseman is upside down / Piranhaman is swimming / Hawkman is flying
boolean heroJ = false; // hero is jumping
boolean heroS = false; // hero is using sword / Lizardman is firing
boolean heroH = false; // hero is hurt/hit

void setup() {
  arduboy.begin();
  arduboy.setFrameRate(20);
  //arduboy.initRandomSeed();
}

void loop() {

  // pause render until it's time for the next frame
  if (!(arduboy.nextFrame()))
    return;

  // handle change of direction
  if (heroR && arduboy.pressed(LEFT_BUTTON))
    heroR = false;
  else if (!heroR && arduboy.pressed(RIGHT_BUTTON))
    heroR = true;
  
  // handle jumping
  if (!heroJ && arduboy.pressed(B_BUTTON)) { // jump init
    anim = 10;  // 10 animation steps
    heroJ = true;
  }

  // handle using sword
  if (!heroS && arduboy.pressed(A_BUTTON)) { // sword init
    if (!heroJ) anim = 10;  // 10 animation steps
    heroS = true;
  }

  // handle crouching
  heroD = (!heroJ && !heroS && arduboy.pressed(DOWN_BUTTON));

  // set screen white
  arduboy.fillScreen(WHITE);

  // display hero tile
  switch (heroT) {  // switch on "hero type"
    case HUMAN:
      if (heroS) {        // using sword
        if (heroD) {
          if (heroR)  sprites.drawPlusMask(heroX-16, heroY-16, HUMANRDS_plus_mask, 0);  // crouching + sword right
          else        sprites.drawPlusMask(heroX-16, heroY-16, HUMANLDS_plus_mask, 0);  // crouching + sword left
        } else {
          if (heroR)  sprites.drawPlusMask(heroX-16, heroY-27, HUMANRS_plus_mask, 0);  // walking/jumping + sword right
          else        sprites.drawPlusMask(heroX-16, heroY-27, HUMANLS_plus_mask, 0);  // walking/jumping + sword left
        }
      } else if (heroD) { // crouching
        if (heroR)  sprites.drawPlusMask(heroX-12, heroY-16, HUMANRD_plus_mask, 0);   // crouching right
        else        sprites.drawPlusMask(heroX-12, heroY-16, HUMANLD_plus_mask, 0);   // crouching left
      } else if (heroH) { // hurt
        sprites.drawPlusMask(heroX-12, heroY-27, HUMANH_plus_mask, 0);
      } else if (heroJ) { // jumping
        if (heroR) {
          sprites.drawPlusMask(heroX-12, heroY-30, HUMANR_plus_mask, 0);  // jumping right (face)
          sprites.drawPlusMask(heroX-12, heroY-15, HUMANR_plus_mask, 3);  // jumping right (body)
        } else {
          sprites.drawPlusMask(heroX-12, heroY-28, HUMANL_plus_mask, 0);  // jumping left (face)
          sprites.drawPlusMask(heroX-12, heroY-14, HUMANL_plus_mask, 3);  // jumping left (body)
        }
      } else {            // walking
        if (heroR) {
          sprites.drawPlusMask(heroX-12, heroY-30, HUMANR_plus_mask, 0);     // walking right (face)
          sprites.drawPlusMask(heroX-12, heroY-15, HUMANR_plus_mask, anim);  // walking right (body)
        } else {
          sprites.drawPlusMask(heroX-12, heroY-28, HUMANL_plus_mask, 0);     // walking left (face)
          sprites.drawPlusMask(heroX-12, heroY-14, HUMANL_plus_mask, anim);  // walking left (body)
        }
      }
      break;

    case LIZARDMAN:
      break;

    case MOUSEMAN:
      break;

    case PIRANHAMAN:
      break;

    case LIONMAN:
      break;

    case HAWKMAN: default:
      break;

  } // end switch "hero type"

  // next animation step
  if (heroS || heroJ) {
    anim--;
    if (0 == anim) {        // end of jump/sword hit
      heroJ = false;
      heroS = false;
    }
  }
  if (heroJ) {
    if (anim > 5) heroY--;  // going up
    else          heroY++;  // falling down
  } else if (!heroD && (arduboy.pressed(LEFT_BUTTON) || arduboy.pressed(RIGHT_BUTTON))) {
    anim = (anim + 1) % 3; // change walking animation
  }

  // refresh screen
  arduboy.display(CLEAR_BUFFER);

} // end loop()

